# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['noggin',
 'noggin.controller',
 'noggin.form',
 'noggin.representation',
 'noggin.security',
 'noggin.tests',
 'noggin.tests.integration',
 'noggin.tests.unit',
 'noggin.tests.unit.controller',
 'noggin.tests.unit.form',
 'noggin.tests.unit.representation',
 'noggin.tests.unit.security',
 'noggin.tests.unit.translations',
 'noggin.tests.unit.utility',
 'noggin.themes',
 'noggin.utility']

package_data = \
{'': ['*'],
 'noggin': ['static/css/*',
            'static/fonts/*',
            'static/fonts/font-awesome/*',
            'static/js/*',
            'static/js/vendor/corejs-typeahead-1.2.1/*',
            'static/js/vendor/jquery-qrcode-1.0/*',
            'static/js/vendor/jquery.dirty-0.7.2/*',
            'static/js/vendor/moment-2.24.0/*',
            'static/js/vendor/moment-timezone-0.5.28-2019c/*',
            'static/js/vendor/selectize-0.12.6/*',
            'templates/*',
            'translations/*',
            'translations/fi/LC_MESSAGES/messages.po',
            'translations/fr_FR/LC_MESSAGES/messages.po',
            'translations/he/LC_MESSAGES/messages.po',
            'translations/ko/LC_MESSAGES/messages.po',
            'translations/pt_BR/LC_MESSAGES/messages.po',
            'translations/pt_PT/LC_MESSAGES/messages.po',
            'translations/tr/LC_MESSAGES/messages.po',
            'translations/uk/LC_MESSAGES/messages.po'],
 'noggin.tests.unit': ['cassettes/*', 'cassettes/test_signals/*'],
 'noggin.tests.unit.controller': ['cassettes/test_authentication/*',
                                  'cassettes/test_forgot_password/*',
                                  'cassettes/test_group/*',
                                  'cassettes/test_password_reset/*',
                                  'cassettes/test_registration/*',
                                  'cassettes/test_root/*',
                                  'cassettes/test_user/*',
                                  'cassettes/test_user_otp/*'],
 'noggin.tests.unit.security': ['cassettes/test_ipa/*'],
 'noggin.tests.unit.translations': ['cassettes/test_translations/*'],
 'noggin.tests.unit.utility': ['cassettes/test_controllers/*',
                               'cassettes/test_pagination/*'],
 'noggin.themes': ['centos/static/css/*',
                   'centos/static/fonts/*',
                   'centos/static/images/*',
                   'centos/static/vendor/bootstrap-4.3.1/*',
                   'centos/static/vendor/font-awesome-4.7.0/css/*',
                   'centos/static/vendor/font-awesome-4.7.0/fonts/*',
                   'centos/static/vendor/jquery/*',
                   'centos/static/vendor/popper-1.14.7/*',
                   'centos/templates/*',
                   'default/static/css/*',
                   'default/static/vendor/bootstrap-4.3.1/*',
                   'default/static/vendor/jquery/*',
                   'default/static/vendor/popper-1.14.7/*',
                   'default/templates/*',
                   'fas/static/css/*',
                   'fas/static/favicon/*',
                   'fas/static/fonts/*',
                   'fas/static/fonts/hack/eot/*',
                   'fas/static/fonts/hack/eot/latin/*',
                   'fas/static/fonts/hack/web-ttf/*',
                   'fas/static/fonts/hack/web-ttf/latin/*',
                   'fas/static/fonts/hack/woff/*',
                   'fas/static/fonts/hack/woff/latin/*',
                   'fas/static/fonts/hack/woff2/*',
                   'fas/static/fonts/hack/woff2/latin/*',
                   'fas/static/fonts/open-sans/*',
                   'fas/static/images/*',
                   'fas/static/js/fedora-bootstrap/*',
                   'fas/static/js/jquery/*',
                   'fas/templates/*',
                   'openSUSE/static/css/*',
                   'openSUSE/static/images/favicons/*',
                   'openSUSE/static/images/logo/*',
                   'openSUSE/static/js/*',
                   'openSUSE/static/js/jquery/*',
                   'openSUSE/templates/*']}

install_requires = \
['Flask-Mail>=0.9.1,<0.10.0',
 'backoff>=1.10.0,<2.0.0',
 'click>=7.0,<8.0',
 'cryptography>=2.9,<3.0',
 'fedora-messaging>=2.0.1,<3.0.0',
 'flask-babel>=1.0.0,<2.0.0',
 'flask-healthz>=0.0.1,<0.0.2',
 'flask-talisman>=0.7.0,<0.8.0',
 'flask-wtf>=0.14,<0.15',
 'flask>=1.1,<2.0',
 'markupsafe>=1.1.1,<2.0.0',
 'noggin-messages>=0.0.1,<0.0.2',
 'pyjwt>=1.7.1,<2.0.0',
 'pyotp>=2.6.0,<3.0.0',
 'python-freeipa>=1.0.6,<2.0.0',
 'requests[security]>=2.25.1,<3.0.0',
 'translitcodec==0.6.0',
 'unidecode>=1.2.0,<2.0.0',
 'whitenoise>=5.0.1,<6.0.0',
 'wtforms[email]>=2.3.3,<3.0.0']

extras_require = \
{'deploy': ['gunicorn>=20.0,<21.0']}

setup_kwargs = {
    'name': 'noggin-aaa',
    'version': '1.2.0',
    'description': 'Noggin is a self-service portal for FreeIPA. The primary purpose of the portal is to allow users to sign up and manage their account information and group membership.',
    'long_description': '# Noggin\n\n*noggin* is a self-service portal for FreeIPA.\nThe primary purpose of the portal is to allow users to sign up and manage their\naccount information and group membership.\n\nThe documentation is available online at https://noggin-aaa.readthedocs.io/\n',
    'author': 'Fedora Infrastructure',
    'author_email': 'admin@fedoraproject.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fedora-infra/noggin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
